# MolmodelConfig.cmake

# This should define the following:
#   Molmodel_FOUND - Whether search for Molmodel libraries and headers succeeded.
#   Molmodel_ROOT_DIR - the installation directory; all the pieces must be
#                       found together
#   Molmodel_INCLUDE_DIR - location of Molmodel header files
#   Molmodel_LIB_DIR     - location of libmolmodel.{a,so,dylib} or molmodel.lib
#   Molmodel_BIN_DIR     - location of .dll's on Windows
#   Molmodel_LIBRARIES   - suitable for target_link_libraries(); includes
#                          both optimized and debug libraries if both are
#                          available
#   Molmodel_STATIC_LIBRARIES - suitable for target_link_libraries(); includes
#                               both optimized and debug static libraries if
#                               both are available


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was MolmodelConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/x86_64-linux-gnu/cmake/molmodel/" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set_and_check(Molmodel_ROOT_DIR
              "${PACKAGE_PREFIX_DIR}")

set_and_check(Molmodel_INCLUDE_DIR
              "${PACKAGE_PREFIX_DIR}/include/molmodel")

set_and_check(Molmodel_LIB_DIR
              "${PACKAGE_PREFIX_DIR}/lib/x86_64-linux-gnu")

list(APPEND Molmodel_BIN_DIR
            "${PACKAGE_PREFIX_DIR}/bin")

list(APPEND Molmodel_CFLAGS
            -I"${PACKAGE_PREFIX_DIR}/include/molmodel")

list(APPEND Molmodel_LDFLAGS
            -L"${PACKAGE_PREFIX_DIR}/lib/x86_64-linux-gnu")

include("${CMAKE_CURRENT_LIST_DIR}/MolmodelTargets.cmake")

if (TRUE)
    set(Molmodel_LIBRARIES SimTKmolmodel)
else ()
    set(Molmodel_LIBRARIES Molmodel_LIBRARIES-NOTFOUND)
endif ()

if (FALSE)
    set(Molmodel_STATIC_LIBRARIES SimTKmolmodel_static)
else ()
    set(Molmodel_STATIC_LIBRARIES Molmodel_STATIC_LIBRARIES-NOTFOUND)
endif ()

mark_as_advanced(Molmodel_LIBRARIES Molmodel_STATIC_LIBRARIES)

check_required_components(Molmodel)
